Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: src/utils/SkTextureCompressor.h

Issue 417933005: Add preliminary ASTC encoder (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Fix comments Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/utils/SkTextureCompressor.h
diff --git a/src/utils/SkTextureCompressor.h b/src/utils/SkTextureCompressor.h
index a7afe0384b041f196b3bccb4baf1d66e32241d34..cb640058bbbaa5aea344f0e16d921a0134882254 100644
--- a/src/utils/SkTextureCompressor.h
+++ b/src/utils/SkTextureCompressor.h
@@ -18,8 +18,9 @@ namespace SkTextureCompressor {
// Various texture compression formats that we support.
enum Format {
// Alpha only formats.
- kLATC_Format, // 4x4 blocks, compresses A8
- kR11_EAC_Format, // 4x4 blocks, compresses A8
+ kLATC_Format, // 4x4 blocks, compresses A8
+ kR11_EAC_Format, // 4x4 blocks, compresses A8
+ kASTC_12x12_Format, // 12x12 blocks, compresses A8
robertphillips 2014/07/24 17:47:39 Change kLast_Format too ?
krajcevski 2014/07/24 19:59:07 Done.
kLast_Format = kR11_EAC_Format
};

Powered by Google App Engine
This is Rietveld 408576698